;; Generated package description from ob-asymptote.el  -*- no-byte-compile: t -*-
(define-package "ob-asymptote" "1.0.1" "Babel Functions for Asymptote" 'nil :commit "2afd4ebe1162cfdecd1206d8fe73a9e35c452b3a" :maintainer '("Jarmo Hurri" . "jarmo.hurri@iki.fi") :keywords '("literate programming" "reproducible research") :url "https://github.com/hurrja/ob-asymptote")
